==> haskell-hls-splice-plugin-1.1.0.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-splice-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-splice-plugin-1.1.0.0-GNGSUmguQwIEvcKryTQafv
key:                  hls-splice-plugin-1.1.0.0-GNGSUmguQwIEvcKryTQafv
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  dc8fcb63f05c03da0240b6b8ca9801f4
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-splice-plugin-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-splice-plugin-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-1.1.0.0-GNGSUmguQwIEvcKryTQafv
depends:
    aeson-2.1.2.1-A1BsFbrv9iTYSCFmVNKuj base-4.16.4.0
    containers-0.6.5.1 dlist-1.0-H3nZuV4Cu6x25BMSdMVFHl
    extra-1.7.16-DVxFkxw4Jbm8VUOqVAQU72
    foldl-1.4.17-8OoSBXidsMDDyKmw0A42ta ghc-9.2.8
    ghc-exactprint-1.5.0-BFqoNTT8kdm1PXpEaVECZp
    ghcide-1.10.0.0-9b5uoYhHFSz3XRArHf5tgp
    hls-plugin-api-1.6.0.0-1R0dXSBU3kB6HlLBoG0nJK
    hls-refactor-plugin-1.2.0.0-LIF9UnHaGpsKWdZDdDXx8K
    lens-5.2.3-HSZB5kpZAt0LoMCL0cbf2Z
    lsp-1.6.0.0-AIqSqbIniDC70qkr7eb7mA
    retrie-1.2.3-2RO9kTX2jKYKEyKFXlT1bA
    syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V text-1.2.5.0
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-E7OuZmBexWvK28rs1X57rg

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-splice-plugin-1.1.0.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-splice-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-splice-plugin-1.1.0.0-1qlFtrDkFCQ54a3dIS7Efv
key:                  hls-splice-plugin-1.1.0.0-1qlFtrDkFCQ54a3dIS7Efv
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e09ed9852ec7efd8c460f15f791d8635
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-splice-plugin-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-splice-plugin-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-1.1.0.0-1qlFtrDkFCQ54a3dIS7Efv
depends:
    aeson-2.1.2.1-A1BsFbrv9iTYSCFmVNKuj base-4.16.4.0
    containers-0.6.5.1 dlist-1.0-H3nZuV4Cu6x25BMSdMVFHl
    extra-1.7.16-DVxFkxw4Jbm8VUOqVAQU72
    foldl-1.4.17-8OoSBXidsMDDyKmw0A42ta ghc-9.2.8
    ghc-exactprint-1.5.0-BFqoNTT8kdm1PXpEaVECZp
    ghcide-1.10.0.0-KRc2KryvScTK3RpCBGTMVu
    hls-plugin-api-1.6.0.0-6VVt1YLZyNC5ScbCtPi6h2
    hls-refactor-plugin-1.2.0.0-8JWgB4H2Xd95yIem4EcSoF
    lens-5.2.3-HSZB5kpZAt0LoMCL0cbf2Z
    lsp-1.6.0.0-AIqSqbIniDC70qkr7eb7mA
    retrie-1.2.3-2RO9kTX2jKYKEyKFXlT1bA
    syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V text-1.2.5.0
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-E7OuZmBexWvK28rs1X57rg

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
